@@ -210,8 +210,8 @@ class TestMetadata:
         fake_env(
             tmpdir,
             '[metadata]\n'
-            'author-email = test@test.com\n'
-            'home-page = http://test.test.com/test/\n'
+            'author_email = test@test.com\n'
+            'home_page = http://test.test.com/test/\n'
             'summary = Short summary\n'
             'platform = a, b\n'
             'classifier =\n'
@@ -507,6 +507,25 @@ class TestMetadata:
             with get_dist(tmpdir):
                 pass
 
+    def test_dash_to_underscore_warning(self, tmpdir):
+        # dash_to_underscore_warning() is a method in setuptools.dist
+        # remove this test and method when dash convert to underscore in setup.cfg
+        # is no longer supported
+        fake_env(
+            tmpdir,
+            '[metadata]\n'
+            'author-email = test@test.com\n'
+            'maintainer_email = foo@foo.com\n'
+            )
+        msg = ("Usage of dash-separated 'author-email' will not be supported "
+               "in future versions. "
+               "Please use the underscore name 'author_email' instead")
+        with pytest.warns(UserWarning, match=msg):
+            with get_dist(tmpdir) as dist:
+                metadata = dist.metadata
+                assert metadata.author_email == 'test@test.com'
+                assert metadata.maintainer_email == 'foo@foo.com'
+
 
 class TestOptions:
 
@@ -772,6 +791,20 @@ class TestOptions:
             }
             assert dist.metadata.provides_extras == set(['pdf', 'rest'])
 
+    def test_dash_preserved_extras_require(self, tmpdir):
+        fake_env(
+            tmpdir,
+            '[options.extras_require]\n'
+            'foo-a = foo\n'
+            'foo_b = test\n'
+        )
+
+        with get_dist(tmpdir) as dist:
+            assert dist.extras_require == {
+                'foo-a': ['foo'],
+                'foo_b': ['test']
+            }
+
     def test_entry_points(self, tmpdir):
         _, config = fake_env(
             tmpdir,
